from typing import List
from odin_messages.base import BaseEventMessage


class UpdateLimitOrderMessage(BaseEventMessage):
    old_order_ids: List[str]
    exchange: str
    market_code: str
    new_limit_price: float
    new_quantity: float
    usd_price: float
    price_delta: float
    selling: bool


class NewLimitOrderMessage(BaseEventMessage):
    exchange: str
    market_code: str
    limit_price: float
    quantity: float
    usd_price: float
    price_delta: float
    selling: bool

class NewArbitrageSpotTradeMessage(BaseEventMessage):
    generator_order_id: str
    generator_order_status: str
    generator_order_type: str
    origin_exchange: str
    target_exchange: str
    origin_market: str
    target_market: str
    amount: float
    usd_observed: float



class NewSpotOrderMessage(BaseEventMessage):
    exchange: str
    order_id: str
    market_code: str
    quantity: float
    usd_price: float
    selling: bool


class UpdateOrderMessage(BaseEventMessage):
    order_id: str
    market_code: str
    exchange: str
    new_limit_price: float
    new_quantity: float

class CancelOrderByIdMessage(BaseEventMessage):
    order_id: str
    exchange: str
    market_code: str


class CancelAllOrdersMessage(BaseEventMessage):
    exchange: str

class CancelOrdersByMarketMessage(BaseEventMessage):
    exchange: str
    market_code: str




from typing import Dict
from odin_messages.base import BaseEventMessage

class OperatorLoansConfigMessage(BaseEventMessage):
    loans: Dict[str, float]

class OperatorMinimumToTradeMessage(BaseEventMessage):
    exchange: str
    minimumt_to_trade: Dict[str, float]


class OperatorCostConfigMessage(BaseEventMessage):
    exchange: str
    fee: float

class OperatorIsActiveMessage(BaseEventMessage):
    active: bool



from typing import List
from pydantic import BaseModel


class BaseEventMessage(BaseModel):
    event: str
    time: float
    strategy_id: str

class BaseEventMessageArray(BaseModel):
    event: str
    time: float
    strategy_id: str
    exchange: str
    messages: List[BaseEventMessage]


from pydantic import BaseModel

from odin_messages.base import BaseEventMessage


class PriceWatchMessage(BaseEventMessage):
    exchange: str
    market_code: str
    ask_price: float
    ask_delta: float
    bid_price: float
    bid_delta: float

class OneSidePriceWatchMessage(BaseEventMessage):
    exchange: str
    market_code: str
    price: float
    delta: float

class NewUSDPriceMessage(BaseEventMessage):
    ask: float
    bid: float
